@@ -11,6 +11,7 @@ class initial_tanf_eligibility(Variable):
     def formula(spm_unit, period, parameters):
         ied = spm_unit("tanf_initial_employment_deduction", period)
         earned_income = spm_unit("tanf_gross_earned_income", period)
-        net_earned_income = earned_income - ied
+        unearned_income = spm_unit("tanf_gross_unearned_income", period)
+        net_earned_income = earned_income + unearned_income - ied
         payment_level = spm_unit("tanf_max_amount", period)
         return net_earned_income <= payment_level
